# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

"""
Represent a swagger document as a Python namespace for easy traversing and dot
style referencing.
"""

from azdata.cli.core.swagger import Swagger


class AppSwagger(Swagger):
    """
    Represents the app swagger as a condensed namespace.
    """
    def __init__(self, swag):
        super(AppSwagger, self).__init__(swag)

    @property
    def path(self):
        """
        Get the app swagger path.
        """
        path = list(vars(self._swag.paths).keys())[0]
        return path.strip('/')

    @property
    def host(self):
        """
        Get the app host.
        """
        return '{}://{}'.format(self._swag.schemes[0], self._swag.host)

    @property
    def base_path(self):
        """
        Get the app base URL.
        """
        return self._swag.basePath.rstrip('/')

    @property
    def input_parameters(self):
        """
        Get the app swagger inputs.
        """
        inputs = None

        if self._swag.definitions.InputParameters and \
                self._swag.definitions.InputParameters.properties:
            inputs = self._swag.definitions.InputParameters.properties

        return inputs

    @property
    def output_parameters(self):
        """
        Get the app swagger outputs.
        """
        outputs = None

        if self._swag.definitions.OutputParameters and \
                self._swag.definitions.OutputParameters.properties:
            outputs = self._swag.definitions.OutputParameters.properties

        return outputs

    def get_input_type(self, name):
        """
        Get the app swagger input type given a name.
        """
        params = self.input_parameters
        return object.__getattribute__(params, name).description

    def get_output_type(self, name):
        """
        Get the app swagger output type given a name.
        """
        params = self.output_parameters
        return object.__getattribute__(params, name).description
