# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

from collections import OrderedDict


def order_status(section):
    """
    Order status `dict` sections to the same order the server API handed us.
    NOTE: This is redundant in Python 3.7 however needed for earlier versions.

    :param section: The status `dict` section to order.
    :return: A well defined `OrderedDict` of the given status section.
    """
    def get_dashboards(obj):
        return obj if not obj else OrderedDict([
            ('nodeMetricsUrl', obj['nodeMetricsUrl']),
            ('sqlMetricsUrl', obj['sqlMetricsUrl']),
            ('logsUrl', obj['logsUrl'])
        ])

    def get_instances(obj):
        obj = obj if obj else []
        return [OrderedDict([
            ('instanceName', instance['instanceName']),
            ('state', instance['state']),
            ('healthStatus', instance['healthStatus']),
            ('details', instance['details']),
            ('dashboards', get_dashboards(instance.get('dashboards')))
            ]) for instance in obj]

    def get_resources(obj):
        def new_resource(o):
            return None if 'resourceName' not in o else OrderedDict([
                ('resourceName', o['resourceName']),
                ('state', o['state']),
                ('healthStatus', o['healthStatus']),
                ('details', o['details']),
                ('instances', get_instances(o.get('instances')))
            ])

        obj = obj if obj else []
        if isinstance(obj, dict):
            return new_resource(obj)

        return [new_resource(resource) for resource in obj]

    def get_services(obj):
        def new_service(o):
            return None if 'serviceName' not in o else OrderedDict([
                    ('serviceName', o['serviceName']),
                    ('state', o['state']),
                    ('healthStatus', o['healthStatus']),
                    ('details', o['details']),
                    ('resources', get_resources(o.get('resources')))
                ])

        obj = obj if obj else []
        if isinstance(obj, dict):
            return new_service(obj)

        return [new_service(service) for service in obj]

    def get_bdc(obj):
        return None if 'bdcName' not in obj else OrderedDict([
            ('bdcName', obj['bdcName']),
            ('state', obj['state']),
            ('healthStatus', obj['healthStatus']),
            ('details', obj['details']),
            ('services', get_services(obj.get('services')))
        ])

    return {
        'bdc': get_bdc,
        'services': get_services,
        'resources': get_resources,
        'instances': get_instances,
        'dashboards': get_dashboards
    }.get(section)
