# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------


def load_arguments(self, _):
    from azdata.cli.commands.hdfs import _
    from knack.arguments import ArgumentsContext

    with ArgumentsContext(self, 'bdc hdfs shell') as arg_context:
        pass

    with ArgumentsContext(self, 'bdc hdfs ls') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            default="/",
            help=_('The path to list status.')
        )

    with ArgumentsContext(self, 'bdc hdfs exists') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Path to check for existence.')
        )

    with ArgumentsContext(self, 'bdc hdfs mkdir') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Name of the directory to create.')
        )

    with ArgumentsContext(self, 'bdc hdfs mv') as arg_context:
        arg_context.argument(
            'source_path',
            options_list=['--source-path', '-s'],
            help=_('The directory to move.')
        )

        arg_context.argument(
            'target_path',
            options_list=['--target-path', '-t'],
            help=_('The location to move to.')
        )

    with ArgumentsContext(self, 'bdc hdfs create') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Name of the file to create.')
        )

        arg_context.argument(
            'data',
            options_list=['--data', '-d'],
            default = None,
            required = False,
            help=_('Content of the file.  Meant for simple text content.')
        )

    with ArgumentsContext(self, 'bdc hdfs cat') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Name of the file to read.')
        )

        arg_context.argument(
            'offset',
            default = 0,
            type = int,
            required = False,
            options_list=['--offset'],
            help=_('Number of bytes offset within the file to read.')
        )

        arg_context.argument(
            'length',
            default = 4096,
            type = int,
            required = False,
            options_list=['--length', '-l'],
            help=_('Length of the data to read.')
        )

    with ArgumentsContext(self, 'bdc hdfs rm') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Name of the file to remove.')
        )

    with ArgumentsContext(self, 'bdc hdfs rmr') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Name of the file to remove recursively.')
        )

    with ArgumentsContext(self, 'bdc hdfs chmod') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Name of the file or directory to set permissions on.')
        )

        arg_context.argument(
            'permission',
            required = True,
            options_list=['--permission'],
            help=_('Permission octets to set.  Example "775".')
        )

    with ArgumentsContext(self, 'bdc hdfs chown') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Name of the file or directory to change owner of.')
        )

        arg_context.argument(
            'owner',
            required = False,
            options_list=['--owner'],
            help=_('The owner name to set to.')
        )

        arg_context.argument(
            'group',
            required = False,
            options_list=['--group', '-g'],
            help=_('Group name to set to.')
        )

    with ArgumentsContext(self, 'bdc hdfs acl modify') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Name of the file or directory to modify acl on.')
        )

        arg_context.argument(
            'aclspec',
            required = True,
            options_list=['--aclspec', '-a'],
            help=_('ACL spec to set on file.  Example "user:bob:rw-".')
        )

    with ArgumentsContext(self, 'bdc hdfs acl remove') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Name of the file or directory to remove permissions from.')
        )

        arg_context.argument(
            'aclspec',
            required = False,
            options_list=['--aclspec', '-a'],
            help=_('ACL spec with entries to remove. "default" to remove '
                   'default ACL entries..  Example "user:bob:".')
        )

    with ArgumentsContext(self, 'bdc hdfs acl set') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Name of the file or directory to set acl on.')
        )

        arg_context.argument(
            'aclspec',
            required = True,
            options_list=['--aclspec', '-a'],
            help=_('ACL spec to set on file.  Example "user:bob:rw-".')
        )

    with ArgumentsContext(self, 'bdc hdfs acl status') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Name of the file or directory to get ACL status.')
        )

    with ArgumentsContext(self, 'bdc hdfs xattr get') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Name of the file or directory to get extended attribute '
                   'on.')
        )

        arg_context.argument(
            'name',
            required = True,
            options_list=['--name', '-n'],
            help=_('Name of the extended attribute to retrieve.')
        )

    with ArgumentsContext(self, 'bdc hdfs xattr set') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Name of the file or directory to set extended attribute '
                   'on.')
        )

        arg_context.argument(
            'name',
            required = True,
            options_list=['--name', '-n'],
            help=_('Name of the extended attribute to set.')
        )

        arg_context.argument(
            'value',
            required = True,
            options_list=['--value', '-v'],
            help=_('Value of the extended attribute to set.')
        )

    with ArgumentsContext(self, 'bdc hdfs xattr modify') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Name of the file or directory to modify the extended '
                   'attribute on.')
        )

        arg_context.argument(
            'name',
            required = True,
            options_list=['--name', '-n'],
            help=_('Name of the extended attribute to modify.')
        )

        arg_context.argument(
            'value',
            required = True,
            options_list=['--value', '-v'],
            help=_('Value of the extended attribute to modify.')
        )

    with ArgumentsContext(self, 'bdc hdfs xattr remove') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Name of the file or directory to remove extended attribute '
                   'on.')
        )

        arg_context.argument(
            'name',
            required = True,
            options_list=['--name', '-n'],
            help=_('Name of the extended attribute to remove.')
        )

    with ArgumentsContext(self, 'bdc hdfs xattr status') as arg_context:
        arg_context.argument(
            'path',
            options_list=['--path', '-p'],
            help=_('Name of the file or directory to get extended attributes '
                   'for.')
        )

    with ArgumentsContext(self, 'bdc hdfs cp') as arg_context:
        arg_context.argument(
            'from_path',
            options_list=['--from-path', '-f'],
            help=_('Name of the path to copy from.  Prefix the path with "hdfs:" to indicate an HDFS path.')
        )

        arg_context.argument(
            'to_path',
            options_list=['--to-path', '-t'],
            help=_('Name of the path to copy to.  Prefix the path with "hdfs:" to indicate an HDFS path.')
        )

    with ArgumentsContext(self, 'bdc hdfs mount create') as arg_context:
        arg_context.argument(
            'remote_uri',
            options_list=['--remote-uri', '-r'],
            help=_('URI of the remote store that is to be mounted (source of '
                   'mount).')
        )

        arg_context.argument(
            'mount_path',
            options_list=['--mount-path', '-m'],
            help=_('HDFS path where mount has to be created (destination of '
                   'mount).')
        )

    with ArgumentsContext(self, 'bdc hdfs mount delete') as arg_context:
        arg_context.argument(
            'mount_path',
            options_list=['--mount-path', '-m'],
            help=_('the HDFS path corresponding to the mount that has to be '
                   'deleted.')
        )

    with ArgumentsContext(self, 'bdc hdfs mount status') as arg_context:
        arg_context.argument(
            'mount_path',
            options_list=['--mount-path', '-m'],
            help=_('Mount path.')
        )

    with ArgumentsContext(self, 'bdc hdfs mount refresh') as arg_context:
        arg_context.argument(
            'mount_path',
            options_list=['--mount-path', '-m'],
            help=_('HDFS path corresponding to the mount that has to be '
                   'refreshed.')
        )
