# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------
from azdata.cli.core.constants import (AZDATA_USERNAME, AZDATA_PASSWORD)


def load_arguments(self, _):
    from azdata.cli.core.enums import SecurityStrategy
    from knack.arguments import ArgumentsContext

    with ArgumentsContext(self, 'login') as c:
        # -- Common arguments across groups --
        c.argument(
            'auth',
            options_list='--auth',
            choices=[SecurityStrategy.basic.name, SecurityStrategy.ad.name],
            help='The authentication strategy. Basic or Active Directory '
                 'authentication. Default is "basic" authentication.'
        )

        c.argument(
            'endpoint',
            options_list=('--endpoint', '-e'),
            help='Cluster controller endpoint "https://host:port". If you do '
                 'not want to use this arg, you may use the kube config on your'
                 ' machine. Please ensure the config is located at the default '
                 'location of <user home>/.kube/config or use the KUBECONFIG '
                 'env var.'
        )

        c.argument(
            'accept_eula',
            options_list=('--accept-eula', '-a'),
            help='Do you accept the license terms? [yes/no]. If you do not '
                 'want to use this arg, you may set the environment variable '
                 'ACCEPT_EULA to \'yes\'. The license terms for this product '
                 'can be viewed at https://aka.ms/eula-azdata-en.'
        )

        c.argument(
            'namespace',
            options_list=('--namespace', '-n'),
            help='Namespace of the cluster control plane.'
        )

        # -- Basic Auth Group arguments --
        c.argument(
            'username',
            options_list=('--username', '-u'),
            help='Account user. If you do not want to use this arg, you may set'
                 ' the environment variable {}.'.format(AZDATA_USERNAME),
            arg_group='Basic Authentication'
        )

        # -- Active Directory Group arguments --
        c.argument(
            'principal',
            options_list=['--principal', '-p'],
            help='Your Kerberos realm. In most cases, your Kerberos realm is '
                 'your domain name, in upper-case letters.',
            arg_group='Active Directory Authentication'
        )

    with ArgumentsContext(self, 'context set') as c:
        c.argument(
            'name',
            options_list=('--namespace', '-n'),
            help='Namespace of the context which you\'d like to set.'
        )

    with ArgumentsContext(self, 'context list') as c:
        c.argument(
            'active',
            options_list=('--active', '-a'),
            action='store_true',
            help='List only the currently active context.'
        )

    with ArgumentsContext(self, 'context delete') as c:
        c.argument(
            'name',
            options_list=('--namespace', '-n'),
            help='Namespace of the context which you\'d like to delete.'
        )
