# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------

"""
Read and modify configuration settings related to the CLI, this to include:

1. Controller API

No description provided (generated by Swagger Codegen
https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: v1.0.0

Generated by: https://github.com/swagger-api/swagger-codegen.git

2. CLI global configurations
"""

from __future__ import absolute_import
from six.moves import http_client as httplib
from .__version__ import __title__, __version__
from azdata.cli.core.util import singleton
from base64 import b64encode

import re
import sys
import os
import multiprocessing


@singleton
class Configuration(object):
    """
    The CLI Configuration singleton.
    """

    CLI_NAME = 'azdata'
    """
    The name of the CLI.
    """

    CLI_ENV_VAR_PREFIX = CLI_NAME
    """
    Prefix all environmental variables with name.
    """

    CLI_CONFIG_DIR = os.getenv('{}_CONFIG_DIR'.format(
        CLI_ENV_VAR_PREFIX.upper()), None) or \
        os.path.expanduser(os.path.join('~', '.{}'.format(CLI_NAME)))
    """
    The CLI framework's configuration directory. Defaults to USER HOME.    
    """

    BOOLEAN_STATES = {'1': True, 'yes': True, 'true': True, 'on': True,
                      '0': False, 'no': False, 'false': False, 'off': False,
                      None: False, 'None': False}
    """
    Mapping of different common logical prepositions to boolean equivalent.
    """

    def __init__(self):
        """
        Configuration runtime constructor.
        """

        # -- Default Base url --
        self.host = None

        # -- Always turn off httplib debug --
        httplib.HTTPConnection.debuglevel = 0

        self.user_agent = '{0}/{1}/python'.format(__title__, self.version)

        # -- Temp file folder for downloading files --
        self.temp_folder_path = None

        # -- Log HTTP Rules: Skip logging of header|request|response --
        self._log_api_blacklist = { # defaults (NOTE: Add more when needed)
            'headers': [{
                'url': re.compile('.*?'), # All skip these header value
                'values': ['Authorization']
            }],
            'request': [],
            'response': [
                re.compile('.*/api/v.[0-9]*/token$')  # skip `host/api/v*/token`
            ]
        }

        self._interactive = True if sys.stdin.isatty() else False

        # --- Authentication Settings ---

        # dict to store API key(s)
        self.api_key = {}
        # dict to store API prefix (e.g. Bearer)
        self.api_key_prefix = {}

        # Username for HTTP basic authentication
        self.username = ''
        # Password for HTTP basic authentication
        self.password = ''

        # Debug switch
        self.debug = False
        self.verbose = False

        # --- SSL/TLS verification ---
        self.verify_ssl = False
        self.ssl_ca_cert = None
        self.cert_file = None
        self.key_file = None
        self.assert_hostname = None

        # -- Proxy URL --
        self.proxy = None

        # urllib3 connection pool's maximum number of connections saved
        # per pool. urllib3 uses 1 connection as default value, but this is
        # not the best value when you are making a lot of possibly parallel
        # requests to the same host, which is often the case here.
        # cpu_count * 5 is used as default value to increase performance.
        self.connection_pool_maxsize = multiprocessing.cpu_count() * 5

        # Safe chars for path_param
        self.safe_chars_for_path_param = ''

    @property
    def version(self):
        return __version__

    @property
    def log_api_blacklist(self):
        """
        Gets the map of APIs to hide respective logging attributes.
        """
        return self._log_api_blacklist

    @property
    def interactive(self):
        """
        Get the state on whether to prompt the user interactively if they are
        in an interactive terminal.
        """
        return self._interactive

    @interactive.setter
    def interactive(self, interactive):
        if isinstance(interactive, str):
            interactive = self.BOOLEAN_STATES[interactive.lower()]

        self._interactive = interactive

    @property
    def verify_ssl(self):
        """
        Get the state on whether to skip or verify SSL certificates.
        """
        return self.__verify_ssl

    @verify_ssl.setter
    def verify_ssl(self, verify_ssl):
        """
        Set to skip or verify SSL certificate when calling API from any https
        servers. Default is `False` for the immediate to suppress urllib3
        warnings.

        @TODO: Swap the default to `True` before shipping.
        """
        if isinstance(verify_ssl, str):
            verify_ssl = self.BOOLEAN_STATES[verify_ssl.lower()]

        self.__verify_ssl = verify_ssl or False

        if not self.verify_ssl:
            import urllib3
            urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

    @property
    def ssl_ca_cert(self):
        """
        Get optional certificate file location to verify the peer.
        """
        return self.__ssl_ca_cert

    @ssl_ca_cert.setter
    def ssl_ca_cert(self, ssl_ca_cert):
        """
        Set to customize the certificate file to verify the peer. SSL client
        certificate default, if String, path to ssl client cert file (.pem).
        """
        self.__ssl_ca_cert = ssl_ca_cert

    @property
    def cert_file(self):
        """
        Gets the optional client certificate file location.
        """
        return self.__cert_file

    @cert_file.setter
    def cert_file(self, cert_file):
        """
        Sets the optional client certificate file location.
        """
        self.__cert_file = cert_file

    @property
    def key_file(self):
        """
        Get the optional client key file location.
        """
        return self.__key_file

    @key_file.setter
    def key_file(self, key_file):
        """
        Set the optional client key file location.
        """
        self.__key_file = key_file

    @property
    def assert_hostname(self):
        """
        Gets the optional SSL hostname verification state.
        """
        return self.__assert_hostname

    @assert_hostname.setter
    def assert_hostname(self, assert_hostname):
        """
        Setter to enable/disable the optional SSL hostname verification.
        """
        if isinstance(assert_hostname, str):
            assert_hostname = self.BOOLEAN_STATES[assert_hostname.lower()]

        self.__assert_hostname = assert_hostname or None

    @property
    def proxy_url(self):
        """
        Gets the optional Proxy URL.
        """
        return self.__proxy_url

    @proxy_url.setter
    def proxy_url(self, proxy_url):
        """
        Sets the optional Proxy URL.
        """
        self.__proxy_url = proxy_url

    @property
    def host(self):
        """
        Gets the controller-plane host endpoint.
        """
        return self.__host

    @host.setter
    def host(self, host):
        """
        Sets the controller-plan host endpoint.
        """
        self.__host = host

    @property
    def user_agent(self):
        """
        Gets the user-agent.
        """
        return self.__user_agent

    @user_agent.setter
    def user_agent(self, user_agent):
        """
        Sets the the user-agent.
        """
        self.__user_agent = user_agent

    @property
    def api_key_prefix(self):
        """
        Gets the api_key_prefix (ex. Bearer).
        """
        return self.__api_key_prefix

    @api_key_prefix.setter
    def api_key_prefix(self, value):
        self.__api_key_prefix = value

    @property
    def verbose(self):
        """
        Gets the verbose status.
        """
        return self.__verbose

    @verbose.setter
    def verbose(self, value):
        """
        Sets the verbose status.

        :param value: The verbose status, True or False.
        :type: bool
        """
        self.__verbose = value

    @property
    def debug(self):
        """
        Gets the debug status.
        """
        return self.__debug

    @debug.setter
    def debug(self, value):
        """
        Sets the debug status.

        :param value: The debug status, True or False.
        :type: bool
        """
        self.__debug = value

    def get_api_key_with_prefix(self, identifier):
        """Gets API key (with prefix if set).

        :param identifier: The identifier of apiKey.
        :return: The token for api key authentication.
        """
        if (self.api_key.get(identifier) and
                self.api_key_prefix.get(identifier)):
            return self.api_key_prefix[identifier] + ' ' + self.api_key[
                identifier]  # noqa: E501
        elif self.api_key.get(identifier):
            return self.api_key[identifier]

    def get_basic_auth_token(self, strip_prefix=False):
        """Gets HTTP basic authentication header (string).

        :return: The token for basic HTTP authentication.
        """

        encoding = b64encode((self.username + ':' +
                              self.password).encode('utf-8'))
        token = 'Basic ' + str(encoding, 'utf-8')

        # remove "Basic" from token format "Basic b64-encoded=="
        if strip_prefix:
            token = token.split()[1]

        return token

    def auth_settings(self):
        return {}

    def to_debug_report(self):
        """
        Gets the essential information for debugging.

        :return: The report for debugging.
        """
        return "CLI Debug Report:\n " \
               "OS: {env}\n" \
               "Version of the API: {version}\n" \
               "Package {name} Version: {pyversion}". \
               format(name=__title__,
                      version=self.version,
                      env=sys.platform,
                      pyversion=sys.version)
