from azdata.cli.core.debug import copy_cluster_and_system_logs
from azdata.cli.core.deploy import display
from azdata.cli.core.logging import get_logger

logger = get_logger(__name__)


def notify_service_endpoint_available(service, endpoint):
    """
    Log the endpoint for the service that is running
    :param service:
    :param endpoint:
    :return:
    """
    if service == "controller":
        # Strip 'https://' to make the endpoint non-clickable
        #
        try:
            endpoint = endpoint.replace('https://', '')
            display("Cluster controller endpoint is available at %s." % endpoint)
        except Exception as e:
            logger.debug(e)


def notify_deployment_error(cluster_name, cluster_state):
    """
    Notify error in deployment and copy debug logs
    :param cluster_name:
    :param cluster_state:
    :return:
    """
    logger.error("Cluster '{0}' deployment failed. Cluster State: {1}.".format(cluster_name, cluster_state))
    copy_cluster_and_system_logs(cluster_name)


def notify_deployment_success(cluster_name):
    """
    Notify successful deployment
    :param cluster_name:
    :return:
    """
    display("Cluster '{0}' deployed successfully.".format(cluster_name))


def notify_upgrade_error(cluster_name, cluster_state):
    """
    Notify error in upgrade and copy debug logs
    :param cluster_name:
    :param cluster_state:
    :return:
    """
    logger.error("Cluster '{0}' upgrade failed. Cluster State: {1}.".format(cluster_name, cluster_state))
    copy_cluster_and_system_logs(cluster_name)


def notify_control_plane_upgrade_paused():
    """
    Notify the user that the control plane upgrade has paused
    :param cluster_name:
    :return:
    """
    display("Control Plane upgrade has been paused. Please examine the Control Plane and either retry " +
                "the upgrade by starting a new upgrade with the same target version, or start a rollback " +
                "by starting an upgrade with the original deployed version.")


def notify_control_plane_upgrade_error(cluster_name, control_plane_state):
    """
    Notify error in upgrade and copy debug logs
    :param cluster_name:
    :param control_plane_state:
    :return:
    """
    logger.error("Control Plane upgrade failed. Control Plane State: %s." % control_plane_state)
    copy_cluster_and_system_logs(cluster_name)


def notify_control_plane_upgrade_success():
    """
    Notify successful control plane upgrade
    """
    display("Control Plane upgraded successfully.")


def notify_bdc_upgrade_error(cluster_name, cluster_state):
    """
    Notify error in upgrade and copy debug logs
    :param cluster_name:
    :param cluster_state:
    :return:
    """
    logger.error("Big Data Cluster '{0}' upgrade failed. Cluster State: {1}.".format(cluster_name, cluster_state))
    copy_cluster_and_system_logs(cluster_name)


def notify_bdc_upgrade_success():
    """
    Notify successful BDC upgrade
    """
    display("Big Data Cluster upgraded successfully.")


def notify_bdc_upgrade_paused():
    """
    Notify the user that the Big Data Cluster upgrade has paused
    :param cluster_name:
    :return:
    """
    display("Big Data Cluster upgrade has been paused. Please examine the Big Data Cluster and either retry " +
                "the upgrade by starting a new upgrade with the same target version, or start a rollback " +
                "by starting an upgrade with the original deployed version.")


def log_progress(response):
    """
    Logs from controller on cluster deployment in progress
    :param response:
    :return:
    """
    if not response:
        return
    elif not response.endswith('\r\n'):
        log = response.rsplit('\r\n', 1)[0]
    else:
        log = response
    for line in log.splitlines():
        split = line.split('| ')
        if line.startswith('INFO'):
            display(split[1])
        elif line.startswith('WARN'):
            logger.warn(split[1])
        elif line.startswith('ERROR'):
            logger.error(split[1])
        elif line.startswith('FATAL'):
            logger.fatal(split[1])
